==> QuickAMS-1.0.7-sources.jar: static/commonOperation/log/log@flow_log.js <==
userBlockMap["log@flow_log"] = {
    "operations": {
        "addFlowLogRowButton": {
            "type": "button",
            "label": "手动执行流程",
            "props": {
                "type": "primary",
            },
            "event": "addItemDialogAction list:1"
        },
        "executeFlow": {
            "type": "button",
            "label": "执行流程",
            "props": {
                "type": "primary",
            },
            "event": "confirm:确认执行吗? executeFlow list:1"
        },
        "addToFlowRecord": {
            "type": "button",
            "label": "添加到流程记录",
            "props": {
                "type": "primary",
            },
            "event": "confirm:确认添加吗? addToFlowRecord"
        },
    },
    "actions":{
        addItemDialogAction(params) {
            let row = params.$prevReturn;
            row.contextData = JSON.stringify(row.contextData);
            let fields = ams.utils.getResourceFields(this, ["name","requestData","flowNameList"]);
            return ams.utils.addItemDialog(this,"/executeFlow",fields);
        },
        executeFlow(params) {
            let row = params.$prevReturn;
            let data = {
                "name": row["name"],
                "requestData": row["requestData"],
                "flowNameList": row["flowNameList"],
            };
            return ams.utils.sendRequest(this,{
                "method": "POST",
                "url": "/executeFlow",
                "data": data
            }, "流程执行完成");
        },
        addToFlowRecord(params){
            let flowRecordBlock = ams.utils.getBlockByTableName("sys@flow_record");
            let resource = ams.resources[flowRecordBlock["resource"]];
            let row = params.$prevReturn;
            let data = {
                "name": row["name"],
                "requestData": JSON.parse(row["requestData"]),
                "flowNameList": row["flowNameList"],
            };
            return ams.utils.sendRequestWithPrefix(this,resource.api.prefix, {
                "method": "POST",
                "url": "/create",
                "data": data
            }, "流程记录添加完毕");
        }
    }
};

==> QuickAMS-1.0.15-sources.jar: static/commonOperation/log/log@flow_log.js <==
userBlockMap[projectName+"|common|log@flow_log"] = {
    "operations": {
        "copyException": {
            "type": "button",
            "label": "复制异常",
            "props": {
                "type": "primary",
            },
            "show": function(row){
                return row.hasOwnProperty("exception");
            },
            "event": "copyException"
        },
        "addFlowLogRowButton": {
            "type": "button",
            "label": "手动执行流程",
            "props": {
                "type": "primary",
            },
            "event": "addItemDialogAction list:1"
        },
        "executeFlow": {
            "type": "button",
            "label": "执行流程",
            "props": {
                "type": "primary",
            },
            "event": "confirm:确认执行吗? executeFlow list:1"
        },
        "addToFlowRecord": {
            "type": "button",
            "label": "添加到流程记录",
            "props": {
                "type": "primary",
            },
            "event": "confirm:确认添加吗? addToFlowRecord"
        },
    },
    "actions":{
        copyException(params){
            let row = params.$prevReturn;
            let exception = row.exception;
            setClipBoard(exception);
            this.$message.success("异常数据已复制到剪贴板");
        },
        addItemDialogAction(params) {
            let row = params.$prevReturn;
            row.contextData = JSON.stringify(row.contextData);
            let fields = ams.utils.getResourceFields(this, ["name","requestData","flowNameList"]);
            return ams.utils.addItemDialog(this,"/executeFlow",fields);
        },
        executeFlow(params) {
            let row = params.$prevReturn;
            let data = {
                "name": row["name"],
                "requestData": row["requestData"],
                "flowNameList": row["flowNameList"],
            };
            return ams.utils.sendRequest(this,{
                "method": "POST",
                "url": "/executeFlow",
                "data": data
            }, "流程执行完成");
        },
        addToFlowRecord(params){
            let row = params.$prevReturn;
            let data = {
                "name": row["name"],
                "requestData": JSON.parse(row["requestData"]),
                "flowNameList": row["flowNameList"],
            };
            return ams.utils.sendRequestWithTableName(this,"sys@flow_record", {
                "method": "POST",
                "url": "/create",
                "data": data
            }, "流程记录添加完毕");
        }
    }
};
